==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/AdditionalUnattendContentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.AdditionalUnattendContentArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.ComponentNames
import com.pulumi.azurenative.compute.kotlin.enums.PassNames
import com.pulumi.azurenative.compute.kotlin.enums.SettingNames
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies additional XML formatted information that can be included in the Unattend.xml file, which is used by Windows Setup. Contents are defined by setting name, component name, and the pass in which the content is applied.
 * @property componentName The component name. Currently, the only allowable value is Microsoft-Windows-Shell-Setup.
 * @property content Specifies the XML formatted content that is added to the unattend.xml file for the specified path and component. The XML must be less than 4KB and must include the root element for the setting or feature that is being inserted.
 * @property passName The pass name. Currently, the only allowable value is OobeSystem.
 * @property settingName Specifies the name of the setting to which the content applies. Possible values are: FirstLogonCommands and AutoLogon.
 */
public data class AdditionalUnattendContentArgs(
    public val componentName: Output<ComponentNames>? = null,
    public val content: Output<String>? = null,
    public val passName: Output<PassNames>? = null,
    public val settingName: Output<SettingNames>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.AdditionalUnattendContentArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.AdditionalUnattendContentArgs =
        com.pulumi.azurenative.compute.inputs.AdditionalUnattendContentArgs.builder()
            .componentName(componentName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .content(content?.applyValue({ args0 -> args0 }))
            .passName(passName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .settingName(settingName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [AdditionalUnattendContentArgs].
 */
@PulumiTagMarker
public class AdditionalUnattendContentArgsBuilder internal constructor() {
    private var componentName: Output<ComponentNames>? = null

    private var content: Output<String>? = null

    private var passName: Output<PassNames>? = null

    private var settingName: Output<SettingNames>? = null

    /**
     * @param value The component name. Currently, the only allowable value is Microsoft-Windows-Shell-Setup.
     */
    @JvmName("gnungyabvmiyqpjr")
    public suspend fun componentName(`value`: Output<ComponentNames>) {
        this.componentName = value
    }

    /**
     * @param value Specifies the XML formatted content that is added to the unattend.xml file for the specified path and component. The XML must be less than 4KB and must include the root element for the setting or feature that is being inserted.
     */
    @JvmName("frhyylyisbykbedk")
    public suspend fun content(`value`: Output<String>) {
        this.content = value
    }

    /**
     * @param value The pass name. Currently, the only allowable value is OobeSystem.
     */
    @JvmName("xvtffvjfjcistjdq")
    public suspend fun passName(`value`: Output<PassNames>) {
        this.passName = value
    }

    /**
     * @param value Specifies the name of the setting to which the content applies. Possible values are: FirstLogonCommands and AutoLogon.
     */
    @JvmName("ebjjljowlbjcoxgx")
    public suspend fun settingName(`value`: Output<SettingNames>) {
        this.settingName = value
    }

    /**
     * @param value The component name. Currently, the only allowable value is Microsoft-Windows-Shell-Setup.
     */
    @JvmName("psjgbaufvhioktyt")
    public suspend fun componentName(`value`: ComponentNames?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.componentName = mapped
    }

    /**
     * @param value Specifies the XML formatted content that is added to the unattend.xml file for the specified path and component. The XML must be less than 4KB and must include the root element for the setting or feature that is being inserted.
     */
    @JvmName("ufcuaqsprsdbqevl")
    public suspend fun content(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The pass name. Currently, the only allowable value is OobeSystem.
     */
    @JvmName("pnmwadlwsqjhylsh")
    public suspend fun passName(`value`: PassNames?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passName = mapped
    }

    /**
     * @param value Specifies the name of the setting to which the content applies. Possible values are: FirstLogonCommands and AutoLogon.
     */
    @JvmName("llfwrlhwhujpqied")
    public suspend fun settingName(`value`: SettingNames?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settingName = mapped
    }

    internal fun build(): AdditionalUnattendContentArgs = AdditionalUnattendContentArgs(
        componentName = componentName,
        content = content,
        passName = passName,
        settingName = settingName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/AdditionalUnattendContentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.AdditionalUnattendContentArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.ComponentNames
import com.pulumi.azurenative.compute.kotlin.enums.PassNames
import com.pulumi.azurenative.compute.kotlin.enums.SettingNames
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies additional XML formatted information that can be included in the Unattend.xml file, which is used by Windows Setup. Contents are defined by setting name, component name, and the pass in which the content is applied.
 * @property componentName The component name. Currently, the only allowable value is Microsoft-Windows-Shell-Setup.
 * @property content Specifies the XML formatted content that is added to the unattend.xml file for the specified path and component. The XML must be less than 4KB and must include the root element for the setting or feature that is being inserted.
 * @property passName The pass name. Currently, the only allowable value is OobeSystem.
 * @property settingName Specifies the name of the setting to which the content applies. Possible values are: FirstLogonCommands and AutoLogon.
 */
public data class AdditionalUnattendContentArgs(
    public val componentName: Output<ComponentNames>? = null,
    public val content: Output<String>? = null,
    public val passName: Output<PassNames>? = null,
    public val settingName: Output<SettingNames>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.AdditionalUnattendContentArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.AdditionalUnattendContentArgs =
        com.pulumi.azurenative.compute.inputs.AdditionalUnattendContentArgs.builder()
            .componentName(componentName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .content(content?.applyValue({ args0 -> args0 }))
            .passName(passName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .settingName(settingName?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [AdditionalUnattendContentArgs].
 */
@PulumiTagMarker
public class AdditionalUnattendContentArgsBuilder internal constructor() {
    private var componentName: Output<ComponentNames>? = null

    private var content: Output<String>? = null

    private var passName: Output<PassNames>? = null

    private var settingName: Output<SettingNames>? = null

    /**
     * @param value The component name. Currently, the only allowable value is Microsoft-Windows-Shell-Setup.
     */
    @JvmName("kslcmmolsocbhskw")
    public suspend fun componentName(`value`: Output<ComponentNames>) {
        this.componentName = value
    }

    /**
     * @param value Specifies the XML formatted content that is added to the unattend.xml file for the specified path and component. The XML must be less than 4KB and must include the root element for the setting or feature that is being inserted.
     */
    @JvmName("ndrpbtgwdheefbjh")
    public suspend fun content(`value`: Output<String>) {
        this.content = value
    }

    /**
     * @param value The pass name. Currently, the only allowable value is OobeSystem.
     */
    @JvmName("afgbgmptvggmiknw")
    public suspend fun passName(`value`: Output<PassNames>) {
        this.passName = value
    }

    /**
     * @param value Specifies the name of the setting to which the content applies. Possible values are: FirstLogonCommands and AutoLogon.
     */
    @JvmName("uupjpkyggbrkcsvy")
    public suspend fun settingName(`value`: Output<SettingNames>) {
        this.settingName = value
    }

    /**
     * @param value The component name. Currently, the only allowable value is Microsoft-Windows-Shell-Setup.
     */
    @JvmName("ysryfgekhhrpbglt")
    public suspend fun componentName(`value`: ComponentNames?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.componentName = mapped
    }

    /**
     * @param value Specifies the XML formatted content that is added to the unattend.xml file for the specified path and component. The XML must be less than 4KB and must include the root element for the setting or feature that is being inserted.
     */
    @JvmName("fcjqqiymadlhercd")
    public suspend fun content(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The pass name. Currently, the only allowable value is OobeSystem.
     */
    @JvmName("akomyvpyemdvcalm")
    public suspend fun passName(`value`: PassNames?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passName = mapped
    }

    /**
     * @param value Specifies the name of the setting to which the content applies. Possible values are: FirstLogonCommands and AutoLogon.
     */
    @JvmName("rxhphpmthucieqhl")
    public suspend fun settingName(`value`: SettingNames?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settingName = mapped
    }

    internal fun build(): AdditionalUnattendContentArgs = AdditionalUnattendContentArgs(
        componentName = componentName,
        content = content,
        passName = passName,
        settingName = settingName,
    )
}
